from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import File, Int, Boolean, String

Aria2C_V0_1_0 = CommandToolBuilder(tool="aria2c", base_command=["aria2c"], inputs=[ToolInput(tag="in_log", input_type=File(optional=True), prefix="--log", doc=InputDocumentation(doc="The file name of the log file. If '-' is\nspecified, log is written to stdout.\nPossible Values: /path/to/file, -\nTags: #basic")), ToolInput(tag="in_dir", input_type=File(optional=True), prefix="--dir", doc=InputDocumentation(doc="The directory to store the downloaded file.\nPossible Values: /path/to/directory\nDefault: /\nTags: #basic, #file")), ToolInput(tag="in_out", input_type=File(optional=True), prefix="--out", doc=InputDocumentation(doc="The file name of the downloaded file. It is\nalways relative to the directory given in -d\noption. When the -Z option is used, this option\nwill be ignored.\nPossible Values: /path/to/file\nTags: #basic, #http, #ftp, #file")), ToolInput(tag="in_split", input_type=Int(optional=True), prefix="--split", doc=InputDocumentation(doc="Download a file using N connections. If more\nthan N URIs are given, first N URIs are used and\nremaining URLs are used for backup. If less than\nN URIs are given, those URLs are used more than\nonce so that N connections total are made\nsimultaneously. The number of connections to the\nsame host is restricted by the\n--max-connection-per-server option. See also the\n--min-split-size option.\nPossible Values: 1-*\nDefault: 5\nTags: #basic, #http, #ftp")), ToolInput(tag="in_file_allocation", input_type=File(optional=True), prefix="--file-allocation", doc=InputDocumentation(doc="Specify file allocation method.\n'none' doesn't pre-allocate file space. 'prealloc'\npre-allocates file space before download begins.\nThis may take some time depending on the size of\nthe file.\nIf you are using newer file systems such as ext4\n(with extents support), btrfs, xfs or NTFS\n(MinGW build only), 'falloc' is your best\nchoice. It allocates large(few GiB) files\nalmost instantly. Don't use 'falloc' with legacy\nfile systems such as ext3 and FAT32 because it\ntakes almost same time as 'prealloc' and it\nblocks aria2 entirely until allocation finishes.\n'falloc' may not be available if your system\ndoesn't have posix_fallocate() function.\n'trunc' uses ftruncate() system call or\nplatform-specific counterpart to truncate a file\nto a specified length.\nPossible Values: none, prealloc, trunc, falloc\nDefault: prealloc\nTags: #basic, #file")), ToolInput(tag="in_check_integrity", input_type=Boolean(optional=True), prefix="--check-integrity", doc=InputDocumentation(doc="[=true|false] Check file integrity by validating piece\nhashes or a hash of entire file. This option has\neffect only in BitTorrent, Metalink downloads\nwith checksums or HTTP(S)/FTP downloads with\n--checksum option. If piece hashes are provided,\nthis option can detect damaged portions of a file\nand re-download them. If a hash of entire file is\nprovided, hash check is only done when file has\nbeen already download. This is determined by file\nlength. If hash check fails, file is\nre-downloaded from scratch. If both piece hashes\nand a hash of entire file are provided, only\npiece hashes are used.\nPossible Values: true, false\nDefault: false\nTags: #basic, #metalink, #bittorrent, #file, #checksum")), ToolInput(tag="in_continue", input_type=Boolean(optional=True), prefix="--continue", doc=InputDocumentation(doc="[=true|false]  Continue downloading a partially downloaded\nfile. Use this option to resume a download\nstarted by a web browser or another program\nwhich downloads files sequentially from the\nbeginning. Currently this option is only\napplicable to http(s)/ftp downloads.\nPossible Values: true, false\nDefault: false\nTags: #basic, #http, #ftp")), ToolInput(tag="in_input_file", input_type=File(optional=True), prefix="--input-file", doc=InputDocumentation(doc="Downloads URIs found in FILE. You can specify\nmultiple URIs for a single entity: separate\nURIs on a single line using the TAB character.\nReads input from stdin when '-' is specified.\nAdditionally, options can be specified after each\nline of URI. This optional line must start with\none or more white spaces and have one option per\nsingle line. See INPUT FILE section of man page\nfor details. See also --deferred-input option.\nPossible Values: /path/to/file, -\nTags: #basic")), ToolInput(tag="in_max_concurrent_downloads", input_type=Int(optional=True), prefix="--max-concurrent-downloads", doc=InputDocumentation(doc="Set maximum number of parallel downloads for\nevery static (HTTP/FTP) URL, torrent and metalink.\nSee also --split and --optimize-concurrent-downloads options.\nPossible Values: 1-*\nDefault: 5\nTags: #basic")), ToolInput(tag="in_force_sequential", input_type=Boolean(optional=True), prefix="--force-sequential", doc=InputDocumentation(doc="[=true|false] Fetch URIs in the command-line sequentially\nand download each URI in a separate session, like\nthe usual command-line download utilities.\nPossible Values: true, false\nDefault: false\nTags: #basic")), ToolInput(tag="in_max_connection_per_server", input_type=Int(optional=True), prefix="--max-connection-per-server", doc=InputDocumentation(doc="The maximum number of connections to one\nserver for each download.\nPossible Values: 1-16\nDefault: 1\nTags: #basic, #http, #ftp")), ToolInput(tag="in_min_split_size", input_type=Int(optional=True), prefix="--min-split-size", doc=InputDocumentation(doc="aria2 does not split less than 2*SIZE byte range.\nFor example, let's consider downloading 20MiB\nfile. If SIZE is 10M, aria2 can split file into 2\nrange [0-10MiB) and [10MiB-20MiB) and download it\nusing 2 sources(if --split >= 2, of course).\nIf SIZE is 15M, since 2*15M > 20MiB, aria2 does\nnot split file and download it using 1 source.\nYou can append K or M(1K = 1024, 1M = 1024K).\nPossible Values: 1048576-1073741824\nDefault: 20M\nTags: #basic, #http, #ftp")), ToolInput(tag="in_ftp_user", input_type=String(optional=True), prefix="--ftp-user", doc=InputDocumentation(doc="Set FTP user. This affects all URLs.\nTags: #basic, #ftp")), ToolInput(tag="in_ftp_passwd", input_type=String(optional=True), prefix="--ftp-passwd", doc=InputDocumentation(doc="Set FTP password. This affects all URLs.\nTags: #basic, #ftp")), ToolInput(tag="in_http_user", input_type=String(optional=True), prefix="--http-user", doc=InputDocumentation(doc="Set HTTP user. This affects all URLs.\nTags: #basic, #http")), ToolInput(tag="in_http_passwd", input_type=String(optional=True), prefix="--http-passwd", doc=InputDocumentation(doc="Set HTTP password. This affects all URLs.\nTags: #basic, #http")), ToolInput(tag="in_load_cookies", input_type=File(optional=True), prefix="--load-cookies", doc=InputDocumentation(doc="Load Cookies from FILE using the Firefox3 format\nand Mozilla/Firefox(1.x/2.x)/Netscape format.\nPossible Values: /path/to/file\nTags: #basic, #http, #cookie")), ToolInput(tag="in_show_files", input_type=Boolean(optional=True), prefix="--show-files", doc=InputDocumentation(doc="[=true|false] Print file listing of .torrent, .meta4 and\n.metalink file and exit. More detailed\ninformation will be listed in case of torrent\nfile.\nPossible Values: true, false\nDefault: false\nTags: #basic, #metalink, #bittorrent")), ToolInput(tag="in_max_overall_upload_limit", input_type=Int(optional=True), prefix="--max-overall-upload-limit", doc=InputDocumentation(doc="Set max overall upload speed in bytes/sec.\n0 means unrestricted.\nYou can append K or M(1K = 1024, 1M = 1024K).\nTo limit the upload speed per torrent, use\n--max-upload-limit option.\nPossible Values: 0-*\nDefault: 0\nTags: #basic, #bittorrent")), ToolInput(tag="in_max_upload_limit", input_type=Int(optional=True), prefix="--max-upload-limit", doc=InputDocumentation(doc="Set max upload speed per each torrent in\nbytes/sec. 0 means unrestricted.\nYou can append K or M(1K = 1024, 1M = 1024K).\nTo limit the overall upload speed, use\n--max-overall-upload-limit option.\nPossible Values: 0-*\nDefault: 0\nTags: #basic, #bittorrent")), ToolInput(tag="in_torrent_file", input_type=File(optional=True), prefix="--torrent-file", doc=InputDocumentation(doc="The path to the .torrent file.\nPossible Values: /path/to/file\nTags: #basic, #bittorrent")), ToolInput(tag="in_listen_port", input_type=Int(optional=True), prefix="--listen-port", doc=InputDocumentation(doc="Set TCP port number for BitTorrent downloads.\nMultiple ports can be specified by using ',',\nfor example: '6881,6885'. You can also use '-'\nto specify a range: '6881-6999'. ',' and '-' can\nbe used together.\nPossible Values: 1024-65535\nDefault: 6881-6999\nTags: #basic, #bittorrent")), ToolInput(tag="in_enable_dht", input_type=Boolean(optional=True), prefix="--enable-dht", doc=InputDocumentation(doc="[=true|false]    Enable IPv4 DHT functionality. It also enables\nUDP tracker support. If a private flag is set\nin a torrent, aria2 doesn't use DHT for that\ndownload even if ``true`` is given.\nPossible Values: true, false\nDefault: true\nTags: #basic, #bittorrent")), ToolInput(tag="in_dht_listen_port", input_type=Int(optional=True), prefix="--dht-listen-port", doc=InputDocumentation(doc="Set UDP listening port used by DHT(IPv4, IPv6)\nand UDP tracker. Multiple ports can be specified\nby using ',', for example: '6881,6885'. You can\nalso use '-' to specify a range: '6881-6999'.\n',' and '-' can be used together.\nPossible Values: 1024-65535\nDefault: 6881-6999\nTags: #basic, #bittorrent")), ToolInput(tag="in_enable_dht_six", input_type=Boolean(optional=True), prefix="--enable-dht6", doc=InputDocumentation(doc="[=true|false]   Enable IPv6 DHT functionality.\nUse --dht-listen-port option to specify port\nnumber to listen on. See also --dht-listen-addr6\noption.\nPossible Values: true, false\nDefault: false\nTags: #basic, #bittorrent")), ToolInput(tag="in_dht_listen_addr_six", input_type=Int(optional=True), prefix="--dht-listen-addr6", doc=InputDocumentation(doc="Specify address to bind socket for IPv6 DHT.\nIt should be a global unicast IPv6 address of the\nhost.\nTags: #basic, #bittorrent")), ToolInput(tag="in_metalink_file", input_type=File(optional=True), prefix="--metalink-file", doc=InputDocumentation(doc="The file path to the .meta4 and .metalink\nfile. Reads input from stdin when '-' is\nspecified.\nPossible Values: /path/to/file, -\nTags: #basic, #metalink"))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Aria2C_V0_1_0().translate("wdl", allow_empty_container=True)

